<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>ApplicationChooser</name>
    <message>
        <location filename="../applicationchooser.ui" line="14"/>
        <source>ApplicationChooser</source>
        <translation>Voľba aplikácie</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="46"/>
        <source>Pick an application for:</source>
        <translation>Vybrať aplikáciu pre:</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="110"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="115"/>
        <source>Applications that handle JPEG</source>
        <translation>Aplikácie spracovávajú JPEG</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="124"/>
        <location filename="../applicationchooser.ui" line="129"/>
        <location filename="../applicationchooser.ui" line="139"/>
        <location filename="../applicationchooser.ui" line="144"/>
        <source>New Subitem</source>
        <translation>Nový podbod</translation>
    </message>
    <message>
        <location filename="../applicationchooser.ui" line="135"/>
        <location filename="../applicationchooser.cpp" line="191"/>
        <location filename="../applicationchooser.cpp" line="217"/>
        <source>Other applications</source>
        <translation>Ostatné aplikácie</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="147"/>
        <source>Web browsers</source>
        <translation>Internetový prehliadač</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="152"/>
        <source>Email clients</source>
        <translation>E-mailový klienti</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="157"/>
        <source>File managers</source>
        <translation>Správcovia súborov</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="193"/>
        <location filename="../applicationchooser.cpp" line="219"/>
        <source>Other applications that handle %1</source>
        <translation>Ostatné aplikácie, ktoré pracujú s % 1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="194"/>
        <location filename="../applicationchooser.cpp" line="220"/>
        <source>Applications that handle %1</source>
        <translation>Aplikácie spracovavajúce %1</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="305"/>
        <source>No applications found</source>
        <translation>Nenájdené žiadne aplikácie</translation>
    </message>
    <message>
        <location filename="../applicationchooser.cpp" line="310"/>
        <source>No more applications found</source>
        <translation>Nenašli sa žiadne ďalšie aplikácie</translation>
    </message>
</context>
<context>
    <name>MimetypeViewer</name>
    <message>
        <location filename="../mimetypeviewer.cpp" line="271"/>
        <location filename="../mimetypeviewer.cpp" line="290"/>
        <location filename="../mimetypeviewer.cpp" line="309"/>
        <source>Change...</source>
        <translation>Zmeniť...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="275"/>
        <location filename="../mimetypeviewer.cpp" line="294"/>
        <location filename="../mimetypeviewer.cpp" line="313"/>
        <location filename="../mimetypeviewer.cpp" line="327"/>
        <location filename="../mimetypeviewer.cpp" line="388"/>
        <source>None</source>
        <translation>Žiadne</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="276"/>
        <location filename="../mimetypeviewer.cpp" line="295"/>
        <location filename="../mimetypeviewer.cpp" line="314"/>
        <source>Choose...</source>
        <translation>Vybrať...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="384"/>
        <source>&amp;Change...</source>
        <translation>&amp;Zmeniť...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.cpp" line="389"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Vybrať...</translation>
    </message>
</context>
<context>
    <name>mimetypeviewer</name>
    <message>
        <location filename="../mimetypeviewer.ui" line="20"/>
        <source>File Associations</source>
        <translation>Predvolené aplikácie</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="30"/>
        <source>Associations</source>
        <translation>Otvoriť pomocou</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="206"/>
        <source>Default application</source>
        <translation>Predvolené aplikácie</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="271"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Vybrať...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="305"/>
        <source>Default Applications</source>
        <translation>Predvolené aplikácie</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="347"/>
        <source>Web Browser</source>
        <translation>Webový prehliadač</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="412"/>
        <location filename="../mimetypeviewer.ui" line="487"/>
        <location filename="../mimetypeviewer.ui" line="562"/>
        <source>Choose...</source>
        <translation>Vybrať...</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="422"/>
        <source>Email Client</source>
        <translation>E-mailový klient</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="497"/>
        <source>File Manager</source>
        <translation>Správca súborov</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="255"/>
        <location filename="../mimetypeviewer.ui" line="396"/>
        <location filename="../mimetypeviewer.ui" line="471"/>
        <location filename="../mimetypeviewer.ui" line="546"/>
        <source>None</source>
        <translation>Žiaden</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="187"/>
        <source>Patterns</source>
        <translation>Vzor</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="193"/>
        <source>*.txt *.xml</source>
        <translation>*.txt *.xml</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="146"/>
        <source>MIME type</source>
        <translation>Typ MIME</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="164"/>
        <location filename="../mimetypeviewer.ui" line="248"/>
        <location filename="../mimetypeviewer.ui" line="389"/>
        <location filename="../mimetypeviewer.ui" line="464"/>
        <location filename="../mimetypeviewer.ui" line="539"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../mimetypeviewer.ui" line="171"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
</context>
</TS>
